import { createStyles } from '@udecode/plate-styled-components';
import _styled, { css } from 'styled-components';
import * as React from 'react';
import { setNodes, getPreventDefaultHandler } from '@udecode/plate-common';
import { useEditorRef, useStoreEditorState, useEventEditorId, getPlatePluginType } from '@udecode/plate-core';
import { ReactEditor } from 'slate-react';
import { CODE_BLOCK_LANGUAGES, ELEMENT_CODE_BLOCK, insertEmptyCodeBlock } from '@udecode/plate-code-block';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import { ToolbarElement } from '@udecode/plate-toolbar';

const getCodeBlockElementStyles = props => createStyles({
  prefixClassNames: 'CodeBlockElement',
  ...props
}, {
  root: [{
    "whiteSpace": "pre-wrap",
    "paddingTop": "0.75rem",
    "paddingBottom": "0.75rem",
    "paddingLeft": "1rem",
    "paddingRight": "1rem"
  }, css(["font-size:16px;font-family:SFMono-Regular,Consolas,Monaco,'Liberation Mono',Menlo,Courier,monospace;tab-size:2;line-height:normal;border-radius:3px;background-color:rgb(247,246,243);"])]
});

const CodeBlockSelectElement = ({
  lang,
  onChange,
  ...props
}) => {
  const [value, setValue] = React.useState(lang);
  return /*#__PURE__*/jsxs("select", {
    value: value,
    style: {
      float: 'right'
    },
    onChange: e => {
      onChange(e.target.value);
      setValue(e.target.value);
    },
    ...props,
    children: [/*#__PURE__*/jsx("option", {
      value: "",
      children: "Plain text"
    }), Object.entries(CODE_BLOCK_LANGUAGES).map(([key, val]) => /*#__PURE__*/jsx("option", {
      value: key,
      children: val
    }, key))]
  });
};

const CodeBlockElement = props => {
  const {
    attributes,
    children,
    element,
    nodeProps
  } = props;
  const {
    lang
  } = element;
  const editor = useEditorRef();
  const {
    root
  } = getCodeBlockElementStyles(props);
  return /*#__PURE__*/jsx(Fragment, {
    children: /*#__PURE__*/jsxs(_StyledPre, { ...attributes,
      className: root.className,
      ...nodeProps,
      $_css: root.css,
      children: [/*#__PURE__*/jsx(CodeBlockSelectElement, {
        "data-testid": "CodeBlockSelectElement",
        lang: lang,
        onChange: val => {
          const path = ReactEditor.findPath(editor, element);
          setNodes(editor, {
            lang: val
          }, {
            at: path
          });
        }
      }), /*#__PURE__*/jsx("code", {
        children: children
      })]
    })
  });
};

var _StyledPre = _styled("pre").withConfig({
  displayName: "CodeBlockElement___StyledPre",
  componentId: "sc-edret1-0"
})(["", ""], p => p.$_css);

const getCodeLineElementStyles = props => createStyles({
  prefixClassNames: 'CodeLineElement',
  ...props
}, {
  root: [{}]
});

const CodeLineElement = props => {
  const {
    attributes,
    children
  } = props;
  const {
    root
  } = getCodeLineElementStyles(props);
  return /*#__PURE__*/jsx(_StyledDiv, { ...attributes,
    className: root.className,
    $_css: root.css,
    children: children
  });
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "CodeLineElement___StyledDiv",
  componentId: "sc-11fh9za-0"
})(["", ""], p => p.$_css);

const ToolbarCodeBlock = ({
  options,
  ...props
}) => {
  const editor = useStoreEditorState(useEventEditorId('focus'));
  return /*#__PURE__*/jsx(ToolbarElement, {
    type: getPlatePluginType(editor, ELEMENT_CODE_BLOCK),
    onMouseDown: editor && getPreventDefaultHandler(insertEmptyCodeBlock, editor, {
      insertNodesOptions: {
        select: true
      },
      ...options
    }),
    ...props
  });
};

export { CodeBlockElement, CodeBlockSelectElement, CodeLineElement, ToolbarCodeBlock, getCodeBlockElementStyles, getCodeLineElementStyles };
//# sourceMappingURL=index.es.js.map
